package ai.pai.lensman.printer;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import ai.pai.lensman.R;

/**
 * Created by chengzhenyu on 2016/9/1.
 */

public class PrinterSettingPresenter implements PrinterSettingContract.Presenter {

    private Context context;
    private PrinterSettingContract.View view;
    private  BluetoothAdapter bluetoothAdapter;

    public PrinterSettingPresenter(Context context, PrinterSettingContract.View view){
        this.view = view;
        this.context = context;
        bluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
    }

    @Override
    public void start() {
        if(queryBluetoothStatus()){
            view.onBluetoothEnabled();
            view.onPairedDeviceDiscovered(queryPairedDevices());
            view.showToast(context.getString(R.string.query_processing));
            queryPrinterStatus();
            discoverNewDevices();
        }else{
            view.onBluetoothDisabled();
            view.showToast(context.getString(R.string.bt_is_disabled));
        }
    }

    @Override
    public void stop() {
        cancelDiscovery();
    }

    @Override
    public void queryPrinterStatus() {

    }

    @Override
    public void printTestPage() {

    }

    @Override
    public boolean queryBluetoothStatus() {
        if(bluetoothAdapter==null){
            return false;
        }
        return bluetoothAdapter.isEnabled();
    }

    @Override
    public List<BluetoothDevice> queryPairedDevices() {
        ArrayList<BluetoothDevice> pairedDevices = new ArrayList<>();
        Set<BluetoothDevice> deviceSet = bluetoothAdapter.getBondedDevices();
        for(BluetoothDevice device: deviceSet){
            pairedDevices.add(device);
        }
        return pairedDevices;

    }

    @Override
    public void discoverNewDevices() {
        // Register for broadcasts when a device is discovered
        IntentFilter filter = new IntentFilter(BluetoothDevice.ACTION_FOUND);
        context.registerReceiver(mFindBlueToothReceiver, filter);
        // Register for broadcasts when discovery has finished
        filter = new IntentFilter(BluetoothAdapter.ACTION_DISCOVERY_FINISHED);
        context.registerReceiver(mFindBlueToothReceiver, filter);
        bluetoothAdapter.startDiscovery();
    }

    @Override
    public void connectPrinter() {

    }

    @Override
    public void cancelDiscovery() {
        try{
            bluetoothAdapter.cancelDiscovery();
            context.unregisterReceiver(mFindBlueToothReceiver);
        }catch (Exception e){
            e.printStackTrace();
        }
    }

    @Override
    public void connectBluetooth(BluetoothDevice device) {

    }

    // changes the title when discovery is finished
    private final BroadcastReceiver mFindBlueToothReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            // When discovery finds a device
            if (BluetoothDevice.ACTION_FOUND.equals(action)) {
                // Get the BluetoothDevice object from the Intent
                BluetoothDevice device = intent
                        .getParcelableExtra(BluetoothDevice.EXTRA_DEVICE);
                // If it's already paired, skip it, because it's been listed
                // already
                if (device.getBondState() != BluetoothDevice.BOND_BONDED) {
                    view.onNewDeviceDiscovered(device);
                }
                // When discovery is finished, change the Activity title
            } else if (BluetoothAdapter.ACTION_DISCOVERY_FINISHED
                    .equals(action)) {
                view.showToast(context.getString(R.string.bt_discover_complete));
            }
        }
    };



}
